summaryrefslogtreecommitdiff
path: root/cmd/podman/registry/registry.go
diff options
context:
space:
mode:
Diffstat (limited to 'cmd/podman/registry/registry.go')
-rw-r--r--cmd/podman/registry/registry.go7
1 files changed, 5 insertions, 2 deletions
diff --git a/cmd/podman/registry/registry.go b/cmd/podman/registry/registry.go
index 1e439613c..9c0b290e7 100644
--- a/cmd/podman/registry/registry.go
+++ b/cmd/podman/registry/registry.go
@@ -12,8 +12,11 @@ import (
"github.com/spf13/cobra"
)
-// DefaultRootAPIAddress is the default address of the REST socket
-const DefaultRootAPIAddress = "unix:/run/podman/podman.sock"
+// DefaultRootAPIPath is the default path of the REST socket
+const DefaultRootAPIPath = "/run/podman/podman.sock"
+
+// DefaultRootAPIAddress is the default address of the REST socket with unix: prefix
+const DefaultRootAPIAddress = "unix:" + DefaultRootAPIPath
// DefaultVarlinkAddress is the default address of the varlink socket
const DefaultVarlinkAddress = "unix:/run/podman/io.podman"